==> geant4.10.00.p02.tar.gz: geant4.10.00.p02/examples/advanced/brachytherapy/src/BrachyActionInitialization.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// Author: S. Guatelli, susanna@uow.edu.au
//
#include "BrachyActionInitialization.hh"
#include "BrachyPrimaryGeneratorAction.hh"
#include "BrachySteppingAction.hh"
#include "G4RunManager.hh"

BrachyActionInitialization::BrachyActionInitialization(BrachyAnalysisManager* analysis_manager):
G4VUserActionInitialization()
{
analysis = analysis_manager;
}


BrachyActionInitialization::~BrachyActionInitialization()
{}

void BrachyActionInitialization::BuildForMaster() const
{
	// In MT mode, to be clearer, the RunAction class for the master thread might be
	// different than the one used for the workers.
	// This RunAction will be called before and after starting the
	// workers.
}


void BrachyActionInitialization::Build() const
{   
 // Initialize the primary particles
BrachyPrimaryGeneratorAction* primary = new BrachyPrimaryGeneratorAction(analysis);
SetUserAction(primary); 

BrachySteppingAction* stepping = new BrachySteppingAction(analysis);
SetUserAction(stepping);
	
}

==> geant4.10.01.tar.gz: geant4.10.01/examples/advanced/brachytherapy/src/BrachyActionInitialization.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// Author: S. Guatelli, susanna@uow.edu.au
//
#include "BrachyActionInitialization.hh"
#include "BrachyPrimaryGeneratorAction.hh"
#include "BrachySteppingAction.hh"
#include "G4RunManager.hh"
#include "G4GeneralParticleSource.hh"

BrachyActionInitialization::BrachyActionInitialization():
G4VUserActionInitialization()
{
 masterGPS = new G4GeneralParticleSource();
}


BrachyActionInitialization::~BrachyActionInitialization()
{
 delete masterGPS;
}

void BrachyActionInitialization::BuildForMaster() const
{
	// In MT mode, to be clearer, the RunAction class for the master thread might be
	// different than the one used for the workers.
	// This RunAction will be called before and after starting the
	// workers.
}


void BrachyActionInitialization::Build() const
{   
 // Initialize the primary particles
BrachyPrimaryGeneratorAction* primary = new BrachyPrimaryGeneratorAction();
SetUserAction(primary); 

BrachySteppingAction* stepping = new BrachySteppingAction();
SetUserAction(stepping);
	
}
